@@ -21,7 +21,7 @@ use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTML::TableExtract;
 
-our $VERSION = '1.38'; # VERSION
+our $VERSION = '1.49'; # VERSION
 
 # URLs of where to obtain information.
 
@@ -62,7 +62,7 @@ sub fundlibrary   {
       $mutual = $_;
       $url = "$FUNDLIB_URL$mutual";
       $reply = $ua->request(GET $url);
-      $te = new HTML::TableExtract(headers => ["Date", "NAVPS"],
+      $te = HTML::TableExtract->new(headers => ["Date", "NAVPS"],
 				   slice_columns => 0);
 
       # Make sure something is returned  ##CAN exit more gracefully - add later##
